==> qcm-debug-1.1.1-2-x86_64.pkg.tar.zst: usr/src/debug/qcm/Qcm/qcm_interface/include/qcm_interface/model/user_account.h <==
#pragma once

#include <map>
#include <QObject>
#include "qcm_interface/model.h"

#include "core/log.h"

namespace qcm
{
namespace model
{
class UserAccount;
struct UserAccountCollection {
    Q_GADGET
public:
    UserAccountCollection(UserAccount*);
    ~UserAccountCollection();

    Q_INVOKABLE bool contains(const ItemId&) const;

private:
    UserAccount* m_parent;
};
class QCM_INTERFACE_API UserAccount : public Model<UserAccount, QObject> {
    Q_OBJECT
    DECLARE_MODEL()

    Q_PROPERTY(UserAccountCollection collection READ collection NOTIFY collectionChanged FINAL)
public:
    UserAccount(QObject* parent = nullptr);
    ~UserAccount();

    DECLARE_PROPERTY(ItemId, userId, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, token, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, nickname, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, avatarUrl, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QUrl, server, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QUrl, session_file, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(Extra, extra, NOTIFY_NAME(infoChanged))
    Q_SIGNAL void infoChanged();

    void insert(const ItemId&);
    void insert(std::span<const ItemId>);
    void remove(const ItemId&);
    bool contains(const ItemId&) const;

    auto collection() const -> const UserAccountCollection&;

    Q_SIGNAL void query();
    Q_SIGNAL void collectionChanged();

private:
    class Private;
    C_DECLARE_PRIVATE(UserAccount, d_ptr);
};

} // namespace model
} // namespace qcm

==> qcm-debug-1.1.2-2-x86_64.pkg.tar.zst: usr/src/debug/qcm/Qcm/qcm_interface/include/qcm_interface/model/user_account.h <==
#pragma once

#include <map>
#include <QObject>
#include <QPointer>
#include "qcm_interface/model.h"

#include "core/log.h"

namespace qcm
{
namespace model
{
class UserAccount;
class UserAccountCollection : public QObject {
    Q_OBJECT
public:
    UserAccountCollection(UserAccount*);
    ~UserAccountCollection();

    Q_INVOKABLE bool contains(const ItemId&) const;

private:
    QPointer<UserAccount> m_parent;
};
class QCM_INTERFACE_API UserAccount : public Model<UserAccount, QObject> {
    Q_OBJECT
    DECLARE_MODEL()

    Q_PROPERTY(UserAccountCollection* collection READ collection NOTIFY collectionChanged FINAL)
public:
    UserAccount(QObject* parent = nullptr);
    ~UserAccount();

    DECLARE_PROPERTY(ItemId, userId, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, token, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, nickname, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QString, avatarUrl, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QUrl, server, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(QUrl, session_file, NOTIFY_NAME(infoChanged))
    DECLARE_PROPERTY(Extra, extra, NOTIFY_NAME(infoChanged))
    Q_SIGNAL void infoChanged();

    void insert(const ItemId&);
    void insert(std::span<const ItemId>);
    void remove(const ItemId&);
    bool contains(const ItemId&) const;

    auto collection() const -> UserAccountCollection*;

    Q_SIGNAL void query();
    Q_SIGNAL void collectionChanged();

private:
    class Private;
    C_DECLARE_PRIVATE(UserAccount, d_ptr);
};

} // namespace model
} // namespace qcm
